**SDK Reference**
=============


SDK
---------
.. automodule:: aymara_ai.core
   :members:
   :undoc-members:
   :show-inheritance:


SDK Types
---------
.. automodule:: aymara_ai.types
   :members:
   :undoc-members:
   :show-inheritance: